Js3dHost class abstract

Factory provided by the host to create concrete 3D controllers for scene3d / model3d nodes.

If a host does not provide a Js3dHost, the renderer falls back to a placeholder for 3D nodes.

Implementers

Constructors

Js3dHost()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, Js3dController controller, Map<String, dynamic> config) Widget
Builds the visual representation of a scene.
createController(String sceneId, Map<String, dynamic> config) Js3dController
Creates a controller for a scene identified by sceneId.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited