JsMediaHost class abstract

Factory provided by the host to create concrete media controllers for video and audio nodes.

If a host does not provide a JsMediaHost, the renderer falls back to placeholder icons for video/audio nodes.

Implementers

Constructors

JsMediaHost()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createAudioController(String src) JsAudioController
Creates an audio controller for src.
createVideoController(String src) JsVideoController
Creates a video controller for src.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited